==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/eu.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federatutako partekatzea",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote}k partekatzen duen {name} urruneko partekatzea gehitu nahi duzu?",
    "Remote share" : "Urruneko partekatzea",
    "Remote share password" : "Urruneko partekatzearen pasahitza",
    "Cancel" : "Ezeztatu",
    "Add remote share" : "Urruneko partekatzea gehitu",
    "Copy" : "Kopiatu",
    "Copied!" : "Kopiatua!",
    "Not supported!" : "Euskarririk ez!",
    "Press ⌘-C to copy." : "Kopiatzeko, sakatu ⌘-C",
    "Press Ctrl-C to copy." : "Kopiatzeko, sakatu Ctrl+C",
    "Invalid Federated Cloud ID" : "Federatutako Hodei ID ezegokia",
    "Server to server sharing is not enabled on this server" : "Zerbitzaritik zerbitzarirako elkarbanaketa ez dago gaituta zerbitzari honetan",
    "Couldn't establish a federated share." : "Ezin izan da urruneko partekatze federatua gehitu.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Ezin izan da urruneko partekatze federatua gehitu, agian pasahitza gaizki dago.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federatutako partekatze eskaera bidali da, gonbidapena jasoko duzu. Notifikazioak begiratu.",
    "The mountpoint name contains invalid characters." : "Muntatze puntuaren izenak baliogabeko karaktereak ditu.",
    "Not allowed to create a federated share with the owner." : "Ez dago baimenik jabearekin federatutako partekatzea sortzeko.",
    "Invalid or untrusted SSL certificate" : "SSL ziurtagiri baliogabea edo fidagaitza",
    "Could not authenticate to remote share, password might be wrong" : "Ezin da urruneko partekatzearekin kautotu, pasahitza gaizki egon daiteke",
    "Storage not valid" : "Biltegi baliogabea",
    "Federated share added" : "Federatutako partekatzea gehituta",
    "Couldn't add remote share" : "Ezin izan da urruneko partekatzea gehitu",
    "Sharing %s failed, because this item is already shared with %s" : "%s elkarbanatzeak huts egin du, dagoeneko %s erabiltzailearekin elkarbanatuta dagoelako",
    "Not allowed to create a federated share with the same user" : "Ezin da erabiltzaile berdinarekin federatutako partekatzea sortu.",
    "File is already shared with %s" : "Fitxategia 1%s-rekin partekatua dago iada",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "1%s partekatzeak huts egin du, ezin da 1%s topatu, agian zerbitzaria ez dago erabilgarri edo berak sinatutako ziurtagiria erabiltzen du.",
    "Could not find share" : "Ezin da partekatzea topatu",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "2%1$s-ren \"1%3$s\" urruneko partekatze bezala jaso duzu ( 3%2$s-en ordez)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user}-en {share} urruneko partekatze bezala jaso duzu ({behalf} ordez)",
    "You received \"%3$s\" as a remote share from %1$s" : "2%1$s-ren \"1%3$s\" urruneko partekatze bezala jaso duzu",
    "You received {share} as a remote share from {user}" : "{user}-en {share} urruneko partekatze bezala jaso duzu",
    "Accept" : "Onartu",
    "Decline" : "Ezeztatu",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Nirekin partekatu #Nextcloud Federatutako Hodei IDa erabiliz, 1%s ikusi",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Nirekin partekatu #Nextcloud Federatutako Hodei IDa erabiliz, ",
    "Sharing" : "Partekatzea",
    "Federated Cloud Sharing" : "Federatutako Hodei Partekatzea",
    "Open documentation" : "Ireki dokumentazioa",
    "Adjust how people can share between servers." : "Pertsonen zerbitzarien arteko partekatzea konfiguratu",
    "Allow users on this server to send shares to other servers" : "Baimendu zerbitzari honetako erabiltzaileak beste zerbitzariekin partekatzera",
    "Allow users on this server to receive shares from other servers" : "Baimendu zerbitzari honetako erabiltzaileak beste zerbitzarietatik partekatutakoak jasotzen",
    "Search global and public address book for users" : "Helbide liburu global eta publikoetak erabiltzaileak bilatu",
    "Allow users to publish their data to a global and public address book" : "Erabiltzaileei bere datuak helbide-liburu publiko eta orokorrean publikatzea baimendu",
    "Federated Cloud" : "Hodei Federatua",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud, ownCloud edo Pydio erabiltzen duen edonorrekin parteka dezakezu! Beraien Federatutako Hodei ID-a idatzi partekatzeen laukian. Honen itxura dute: pertsona@hodei.adibide.com",
    "Your Federated Cloud ID:" : "Federatutatako Hodei ID:",
    "Share it so your friends can share files with you:" : "Partekatu zure lagunek fitxategiak zurekin partekatzeko:",
    "Add to your website" : "Zure webgunera gehitu",
    "Share with me via Nextcloud" : "Partekatu nirekin Nextcloud-en bidez",
    "HTML Code:" : "HTML kodea:",
    "Search global and public address book for users and let local users publish their data" : "Helbide liburu global eta publikoetan erabiltzaileak bilatu eta baimendu erabiltzaileei bere datuak publkatzea",
    "Share it:" : "Partekatu:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.11.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/eu.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote}k partekatzen duen {name} urruneko partekatzea gehitu nahi duzu?",
    "Remote share" : "Urruneko partekatzea",
    "Remote share password" : "Urruneko partekatzearen pasahitza",
    "Cancel" : "Ezeztatu",
    "Add remote share" : "Urruneko partekatzea gehitu",
    "Copy" : "Kopiatu",
    "Copied!" : "Kopiatua!",
    "Not supported!" : "Euskarririk ez!",
    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
    "Invalid Federated Cloud ID" : "Federatutako Hodei ID ezegokia",
    "Server to server sharing is not enabled on this server" : "Zerbitzaritik zerbitzarirako elkarbanaketa ez dago gaituta zerbitzari honetan",
    "Couldn't establish a federated share." : "Ezin izan da urruneko partekatze federatua gehitu.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Ezin izan da urruneko partekatze federatua gehitu, agian pasahitza gaizki dago.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federatutako partekatze eskaera bidali da, gonbidapena jasoko duzu. Notifikazioak begiratu.",
    "Not allowed to create a federated share with the same user" : "Ezin da erabiltzaile berdinarekin federatutako partekatzea sortu.",
    "File is already shared with %s" : "Fitxategia 1%s-rekin partekatua dago iada",
    "Could not find share" : "Ezin da partekatzea topatu",
    "Federated sharing" : "Federatutako partekatzea",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "2%1$s-ren \"1%3$s\" urruneko partekatze bezala jaso duzu ( 3%2$s-en ordez)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user}-en {share} urruneko partekatze bezala jaso duzu ({behalf} ordez)",
    "You received \"%3$s\" as a remote share from %1$s" : "2%1$s-ren \"1%3$s\" urruneko partekatze bezala jaso duzu",
    "You received {share} as a remote share from {user}" : "{user}-en {share} urruneko partekatze bezala jaso duzu",
    "Accept" : "Onartu",
    "Decline" : "Ezeztatu",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Nirekin partekatu #Nextcloud Federatutako Hodei IDa erabiliz, 1%s ikusi",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Nirekin partekatu #Nextcloud Federatutako Hodei IDa erabiliz, ",
    "Sharing" : "Partekatzea",
    "Federated Cloud Sharing" : "Federatutako Hodei Partekatzea",
    "Open documentation" : "Ireki dokumentazioa",
    "Adjust how people can share between servers." : "Pertsonen zerbitzarien arteko partekatzea konfiguratu",
    "Allow users on this server to send shares to other servers" : "Baimendu zerbitzari honetako erabiltzaileak beste zerbitzariekin partekatzera",
    "Allow users on this server to receive shares from other servers" : "Baimendu zerbitzari honetako erabiltzaileak beste zerbitzarietatik partekatutakoak jasotzen",
    "Search global and public address book for users" : "Helbide liburu global eta publikoetak erabiltzaileak bilatu",
    "Allow users to publish their data to a global and public address book" : "Erabiltzaileei bere datuak helbide-liburu publiko eta orokorrean publikatzea baimendu",
    "Federated Cloud" : "Hodei Federatua",
    "Your Federated Cloud ID:" : "Federatutatako Hodei ID:",
    "Share it so your friends can share files with you:" : "Partekatu zure lagunek fitxategiak zurekin partekatzeko:",
    "Add to your website" : "Zure webgunera gehitu",
    "Share with me via Nextcloud" : "Partekatu nirekin Nextcloud-en bidez",
    "HTML Code:" : "HTML kodea:",
    "Sharing %s failed, because this item is already shared with %s" : "%s elkarbanatzeak huts egin du, dagoeneko %s erabiltzailearekin elkarbanatuta dagoelako",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "1%s partekatzeak huts egin du, ezin da 1%s topatu, agian zerbitzaria ez dago erabilgarri edo berak sinatutako ziurtagiria erabiltzen du."
},
"nplurals=2; plural=(n != 1);");
